@@ -67,7 +67,9 @@ namespace LinBox
 		 * @param rs  a rationalSolver
 		 */
 		DiophantineSolver (QSolver& rs) :
-			_rationalSolver(rs), _ring(rs.getRing()), lastCertificate(_ring, 0)
+			_rationalSolver(rs), _ring(rs.getRing())
+			,numSolutionsNeeded(0),numFailedCallsToSolver(0),numRevelantSolutions (0)
+			, lastCertificate(_ring, 0)
 		{ }
 
 		/** Solve a linear system \c Ax=b over quotient field of a ring.
@@ -132,14 +134,16 @@ namespace LinBox
 }
 #include "linbox/algorithms/diophantine-solver.inl"
 
+#ifdef LinBoxSrcOnly
+#include "linbox/algorithms/diophantine-solver.C"
+#endif
+
 #endif //__LINBOX_diophantine_solver_H
 
-
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,:0,t0,+0,=s
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
