@@ -57,14 +57,14 @@ namespace LinBox
 
 		~FastRationalReconstruction() {}
 
-		bool reconstructRational(Element& a, Element& b, const Element& x, const Element& m) const
+		bool RationalReconstruction(Element& a, Element& b, const Element& x, const Element& m) const
 		{
 			Element a_bound; _intRing.sqrt(a_bound, m/2);
-			reconstructRational(a,b,x,m,a_bound);
+			RationalReconstruction(a,b,x,m,a_bound);
 			return (a < a_bound);
 		}
 
-		bool reconstructRational(Element& a, Element& b, const Element& x, const Element& m, const Element& a_bound ) const
+		bool RationalReconstruction(Element& a, Element& b, const Element& x, const Element& m, const Element& a_bound ) const
 		{
 			if (x < a_bound) {
 				//case (i)
@@ -81,7 +81,7 @@ namespace LinBox
 			Element bound = a_bound << 1;
 
 			if (m/bound > 1) {
-				fastReconstructRational(a,b,x,m,m/bound);
+				fastRationalReconstruction(a,b,x,m,m/bound);
 
 				if (_intRing.abs(a) < a_bound) {
 					return true;
@@ -122,7 +122,7 @@ namespace LinBox
 			}
 		}
 
-		Element& powtwo(Element& h, const size_t log_h) const
+		Element& powtwo(Element& h, const uint64_t log_h) const
 		{
 			h = 1;
 			// if (log_h <= 0) return h;
@@ -130,14 +130,14 @@ namespace LinBox
 			return h;
 		}
 
-		bool fastReconstructRational(Element& n, Element& d, const Element& x, const Element& m, const Element& d_bound ) const
+		bool fastRationalReconstruction(Element& n, Element& d, const Element& x, const Element& m, const Element& d_bound ) const
 		{
 
-			size_t log_m = m.bitsize()-1;
-			size_t log_bound = d_bound.bitsize()-1;
+			uint64_t log_m = m.bitsize()-1;
+			uint64_t log_bound = d_bound.bitsize()-1;
 			Element ai, bi, ci, di;
 			ai=1;bi=0;ci=0;di=1;
-			Element bound;  _intRing.powtwo(bound, log_bound);
+			Element bound;  powtwo(bound, log_bound);
 
 			cur_ri = m;
 			cur_rinext = x;
@@ -736,16 +736,16 @@ namespace LinBox
 			,c(0)
 		{}
 
-		bool reconstructRational(Element& a, Element& b, const Element& x, const Element& m) const
+		bool RationalReconstruction(Element& a, Element& b, const Element& x, const Element& m) const
 		{
-			bool res = fastQMaxReconstructRational(a,b,x,m);
+			bool res = fastQMaxRationalReconstruction(a,b,x,m);
 			return res;
 		}
 
-		bool reconstructRational(Element& a, Element& b, const Element& x, const Element& m, const Element& a_bound) const
+		bool RationalReconstruction(Element& a, Element& b, const Element& x, const Element& m, const Element& a_bound) const
 		{
 			// bool res= false;
-			return /*  res = */ FastRationalReconstruction<Ring>::reconstructRational(a,b,x,m,a_bound);
+			return /*  res = */ FastRationalReconstruction<Ring>::RationalReconstruction(a,b,x,m,a_bound);
 		}
 
 	protected:
@@ -757,10 +757,10 @@ namespace LinBox
 		mutable int c;
 
 
-		bool fastQMaxReconstructRational(Element& n, Element& d, const Element& x, const Element& m) const
+		bool fastQMaxRationalReconstruction(Element& n, Element& d, const Element& x, const Element& m) const
 		{
 
-			T = m.bitsize();
+			T =uint64_t( m.bitsize());
 			c = 5; //should be changed here to enhance probability of correctness
 
 			size_t log_m = m.bitsize()-1; //true unless m = 2^k
