@@ -37,6 +37,8 @@
 #include "linbox/util/debug.h"
 
 #include "linbox/blackbox/apply.h"
+#include "linbox/blackbox/diagonal.h"
+#include "linbox/algorithms/matrix-hom.h"
 #include "linbox/algorithms/blackbox-container.h"
 #include "linbox/algorithms/massey-domain.h"
 #include "linbox/algorithms/blackbox-block-container.h"
@@ -152,7 +154,7 @@ namespace LinBox
             Integer N, D, L, Prime;
             this->_intRing.convert(Prime,_p);
 
-            auto hb = RationalSolveHadamardBound(A, b);
+            auto hb = RationalSolveHadamardBound(A, _b);
             N = Integer(1) << static_cast<uint64_t>(std::ceil(hb.numLogBound));
             D = Integer(1) << static_cast<uint64_t>(std::ceil(hb.denLogBound));
 
