@@ -26,7 +26,7 @@
 #ifndef __LINBOX_lambda_sparse_H
 #define __LINBOX_lambda_sparse_H
 
-#include "linbox/blackbox/sparse.h"
+#include "linbox/matrix/sparse-matrix.h"
 #include "linbox/blackbox/archetype.h"
 #include "linbox/vector/stream.h"
 #include "linbox/vector/vector-traits.h"
@@ -61,11 +61,11 @@ namespace LinBox
 			typename Field::RandIter _randiter(F);
 			double                   init_p = 1.0 - 1.0 / (double) card;
 			double                   log_m = LAMBDA * log ((double) m) / M_LN2;
-			double                   new_p;
 
 			RandomSparseStream<Field,typename Vector<Field>::SparseSeq> stream (F, _randiter, init_p, n, m );
 
 			for (unsigned int i = 0; i < m; ++i) {
+			double                   new_p;
 				new_p = log_m / double(m - i);
 
 				if (init_p < new_p)
@@ -86,11 +86,11 @@ namespace LinBox
 			typename Field::RandIter _randiter(F,size,0);
 			double init_p = 1.0 - 1.0 / (double) size;
 			double log_m = LAMBDA * log ((double) m) / M_LN2;
-			double new_p;
 
 			RandomSparseStream<Field,typename Vector<Field>::SparseSeq> stream (F, _randiter, init_p, n, m );
 
 			for (unsigned int i = 0; i < m; ++i) {
+			double new_p;
 				new_p = log_m / double(m - i);
 
 				if (init_p < new_p)
@@ -139,7 +139,7 @@ namespace LinBox
 			for (; iter != this->End(); ++iter)
 				if (*iter > max) max=*iter;
 
-			this->_field.convert(norm,max);
+			this->field().convert(norm,max);
 			return norm;
 		}
 
@@ -152,13 +152,10 @@ namespace LinBox
 
 #endif //__LINBOX_lambda_sparse_H
 
-
-
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,:0,t0,+0,=s
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
