@@ -86,13 +86,16 @@ namespace LinBox
 
 			typename BlasMatrix<Field>::RowIterator row_p;
 
-			std::vector<typename Field::Element> tmp(R.rowdim());
+			// std::vector<typename Field::Element> tmp(R.rowdim());
+			BlasVector<Field> tmp(R.field(),R.rowdim());
 
 			for (row_p = LAR -> rowBegin(), crow_p = L.rowBegin();
 			     row_p != LAR -> rowEnd(); ++ row_p, ++ crow_p) {
 
 				A.applyTranspose(tmp, *crow_p);
 
+				// BlasSubvector<BlasVector<Field> > row_p_v(R.field(),*row_p); //! @warning should not be necessary (RowIterator should be a BlasSubvector...).
+				// R.applyTranspose(row_p_v, tmp);
 				R.applyTranspose(*row_p, tmp);
 			}
 
@@ -105,13 +108,10 @@ namespace LinBox
 
 #endif //__LINBOX_scompose_H
 
-
-
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,:0,t0,+0,=s
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
