@@ -35,7 +35,7 @@
 #include <gmp.h>
 
 #include "linbox/integer.h"
-#include "linbox/field/field-interface.h"
+#include "linbox/field/field-documentation.h"
 #include "linbox/element/gmp-rational.h"
 #include "linbox/linbox-config.h"
 #include "linbox/util/debug.h"
@@ -65,7 +65,7 @@ namespace LinBox
 		typedef RingCategories::RationalTag categoryTag;
 	};
 
-	class GMPRationalField : public FieldInterface {
+	class GMPRationalField : public FieldDocumentation {
 	private:
 
 		const integer _cardinality;
@@ -85,6 +85,12 @@ namespace LinBox
 		/// element type.
 		typedef GMPRationalElement Element;
 
+		/// pointer to element type.
+		typedef GMPRationalElement* Element_ptr;
+		/// const pointer to element type.
+		typedef const Element_ptr ConstElement_ptr;
+
+        
 		/// Random iterator generator type.
 		typedef GMPRationalRandIter RandIter;
 
@@ -445,6 +451,9 @@ namespace LinBox
 		bool isMOne (const Element &x) const
 		{ return mpq_cmp_ui (x.rep, 1L, 1L) == 0; }
 
+		bool isUnit (const Element &x) const
+		{ return !isZero(x); }
+
 
 		/** Inplace Addition.
 		 * x += y
@@ -849,12 +858,10 @@ namespace LinBox
 
 #endif // __LINBOX_field_gmp_rational_H
 
-
-
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
