@@ -5,20 +5,20 @@
  *
  * ------------------------------------
  *
- * 
+ *
  * ========LICENCE========
  * This file is part of the library LinBox.
- * 
+ *
  * LinBox is free software: you can redistribute it and/or modify
  * it under the terms of the  GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -36,10 +36,10 @@
 #include "linbox/linbox-config.h"
 #include "linbox/util/debug.h"
 #include "linbox/integer.h"
-#include "linbox/field/modular.h"
+#include <givaro/modular.h>
 
 #include "linbox/vector/vector-domain.h"
-#include "linbox/field/field-interface.h"
+#include "linbox/field/field-documentation.h"
 #include "linbox/field/field-traits.h"
 #include "linbox/util/field-axpy.h"
 #include <cmath>
@@ -63,11 +63,11 @@ namespace LinBox
 		typedef RingCategories::ModularTag categoryTag;
 	};
 
-	class MultiModDouble : public FieldInterface {
+	class MultiModDouble : public FieldDocumentation {
 
 	protected:
 
-		std::vector<Modular<double> >              _fields;
+		std::vector<Givaro::Modular<double> >              _fields;
 		size_t                                       _size;
 		std::vector<integer>                 _crt_constant;
 		std::vector<double >                  _crt_inverse;
@@ -93,7 +93,7 @@ namespace LinBox
 		{
 			_crt_modulo=1;
 			for (size_t i=0; i<_size; ++i){
-				_fields[i]   .assign( Modular<double> (primes[i]) );
+				_fields[i] = ( Givaro::Modular<double> (primes[i]) );
 				_crt_modulo *= primes[i];
 			}
 			double tmp;
@@ -112,7 +112,7 @@ namespace LinBox
 		{
 			_crt_modulo=1;
 			for (size_t i=0; i<_size; ++i){
-				_fields[i]  .assign( Modular<double> (primes[i]) );
+				_fields[i] = ( Givaro::Modular<double> (primes[i]) );
 				_crt_modulo *= primes[i];
 			}
 			double tmp;
@@ -129,7 +129,7 @@ namespace LinBox
 			_crt_constant(F._crt_constant), _crt_inverse(F._crt_inverse),
 			_crt_modulo(F._crt_modulo) {}
 
-		const MultiModDouble &operator=(const MultiModDouble &F)
+		MultiModDouble &operator=(const MultiModDouble &F)
 		{
 			_fields       = F._fields;
 			_size         = F._size;
@@ -143,11 +143,11 @@ namespace LinBox
 		size_t size() const
 		{return this->_size;}
 
-		const Modular<double>& getBase(size_t i) const
+		const Givaro::Modular<double>& getBase(size_t i) const
 		{ return this->_fields[i]; }
 
-		double getModulo(size_t i) const
-		{ return this->_fields[i].modulus;}
+		Givaro::Modular<double>::Residu_t getModulo(size_t i) const
+		{ return this->_fields[i].characteristic();}
 
 
 		const integer& getCRTmodulo() const
@@ -157,7 +157,7 @@ namespace LinBox
 		{
 			c=1;
 			for (size_t i=0; i<_size; ++i){
-				c*=_fields[i].modulus;
+				c*=getModulo(i);
 			}
 			return c;
 		}
@@ -192,8 +192,8 @@ namespace LinBox
 		{
 			os << "multimod double (";
 			for (size_t i=0;i<_size-1;++i)
-				os<<integer(_fields[i].modulus)<<",";
-			os<<integer(_fields[_size-1].modulus)<<")\n";
+				os<<integer(getModulo(i))<<",";
+			os<<integer(getModulo(_size-1))<<")\n";
 			return os;
 		}
 
@@ -201,9 +201,9 @@ namespace LinBox
 #if 0
 			is >> modulus;
 			if(modulus <= 1)
-				throw PreconditionFailed(__func__,__FILE__,__LINE__,"modulus must be > 1");
+				throw PreconditionFailed(LB_FILE_LOC,"modulus must be > 1");
 			if(modulus > 94906265)
-				throw PreconditionFailed(__func__,__FILE__,__LINE__,"modulus is too big");
+				throw PreconditionFailed(LB_FILE_LOC,"modulus is too big");
 #endif
 			return is;
 		}
@@ -264,6 +264,11 @@ namespace LinBox
 			return x == std::vector<double>(_size, 1.);
 		}
 
+		inline bool isMOne (const Element &x) const
+		{
+			return x == std::vector<double>(_size, -1.); // bug
+		}
+
 		inline Element &add (Element &x, const Element &y, const Element &z) const
 		{
 			for (size_t i=0;i<_size;++i) {
@@ -379,7 +384,7 @@ namespace LinBox
 			return r;
 		}
 
-		static inline double getMaxModulus()
+		static inline double maxCardinality()
 		{ return 94906265.0; } // floor( 2^26.5 )
 
 	};// end of class MultiModField
@@ -392,16 +397,21 @@ namespace LinBox
 
 		MultiModRandIter(const MultiModDouble &F,
 				 const integer   &size=0,
-				 const integer   &seed=0) :
+				 const size_t   &seed=0) :
 			_field(F), _size(size), _seed(seed), _randiter(F._size)
 		{
 			for (size_t i=0;i< F._size;++i)
-				_randiter[i] = new Modular<double>::RandIter(F._fields[i],size,seed) ;
+				_randiter[i] = new Givaro::Modular<double>::RandIter(F._fields[i],seed) ;
 		}
 
-		~MultiModRandIter() {for  (size_t i=0;i< _randiter.size();++i) delete _randiter[i]; }
+		~MultiModRandIter()
+		{
+			for (size_t i=0;i< _randiter.size();++i) 
+				if (_randiter[i])
+					delete _randiter[i];
+		}
 
-		const MultiModRandIter& operator= (const MultiModRandIter &R)
+		MultiModRandIter& operator= (const MultiModRandIter &R)
 		{
 			_seed  = R._seed;
 			_size  = R._size;
@@ -420,14 +430,14 @@ namespace LinBox
 	protected:
 		MultiModDouble        _field;
 		integer                _size;
-		integer                _seed;
-		std::vector<Modular<double>::RandIter*> _randiter;
+		size_t                 _seed;
+		std::vector<Givaro::Modular<double>::RandIter*> _randiter;
 
 	}; // end of class MultiModRandIter
 
 #if 0
 	template <>
-	class DotProductDomain<MultiModDouble > : private virtual VectorDomainBase<MultiModDouble> {
+	class DotProductDomain<MultiModDouble > : private  VectorDomainBase<MultiModDouble> {
 	private:
 		//std::vector<double> _bound;
 		std::vector<size_t>  _nmax;
@@ -513,12 +523,10 @@ namespace LinBox
 
 #endif // __LINBOX_multimod_field_H
 
-
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,:0,t0,+0,=s
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
