@@ -208,8 +208,8 @@ namespace LinBox{
 		 * @param j Column index of entry, 0...coldim() - 1
 		 * @param a_ij Element to set
 		 */
-		const Element& setEntry(size_t i, size_t j, const Element& a_ij){
-			return _Mat->setEntry(_r0 + i, _c0 + j, a_ij);
+		const void setEntry(size_t i, size_t j, const Element& a_ij){
+			_Mat->setEntry(_r0 + i, _c0 + j, a_ij);
 		}
 
 		/** Get a writeable reference to an entry in the matrix.
@@ -414,16 +414,16 @@ namespace LinBox{
 			std::vector<SubmatrixAdapter<Operand2> >& VA,
 			std::vector<SubmatrixAdapter<Operand3> >& VB) const;
 
-		template <class Operand1, class Operand2, class Operand3>
+                template <class Operand1, class Operand2, class Operand3, class Operand4>
 		std::vector<int> oclPartition(
 			Operand1& D,
-			const Operand2& A,
-			const Operand3& B,
-			const Operand1& C,
+			const Operand3& A,
+			const Operand4& B,
+			const Operand2& C,
 			std::vector<SubmatrixAdapter<Operand1> >& VD,
-			std::vector<SubmatrixAdapter<Operand2> >& VA,
-			std::vector<SubmatrixAdapter<Operand3> >& VB,
-			std::vector<SubmatrixAdapter<Operand1> >& VC) const;
+			std::vector<SubmatrixAdapter<Operand3> >& VA,
+			std::vector<SubmatrixAdapter<Operand4> >& VB,
+			std::vector<SubmatrixAdapter<Operand2> >& VC) const;
 
 		void printClErrstring(cl_int err) const;
 #else
@@ -489,42 +489,42 @@ namespace LinBox{
 		//! C = A*B
 		template <class Operand1, class Operand2, class Operand3>
 		Operand1& mul(Operand1& C, const Operand2& A, const Operand3& B) const{
-			return BlasMatrixDomainMul<Field,Operand1,Operand2,Operand3>()(_F,C,A,B);
+			return BlasMatrixDomainMul<Operand1,Operand2,Operand3>()(C,A,B);
 		}
 
 		//! addition.
 		//! C = A+B
 		template <class Operand1, class Operand2, class Operand3>
 		Operand1& add(Operand1& C, const Operand2& A, const Operand3& B) const{
-			return BlasMatrixDomainAdd<Field,Operand1,Operand2,Operand3>()(_F,C,A,B);
+			return BlasMatrixDomainAdd<Operand1,Operand2,Operand3>()(C,A,B);
 		}
 
 		//! copy.
 		//! B = A
 		template <class Operand1, class Operand2>
 		Operand1& copy(Operand1& B, const Operand2& A) const{
-			return BlasMatrixDomainCopy<Field,Operand1,Operand2>()(_F,B,A);
+			return BlasMatrixDomainCopy<Operand1,Operand2>()(B,A);
 		}
 
 		//! substraction
 		//! C = A-B
 		template <class Operand1, class Operand2, class Operand3>
 		Operand1& sub(Operand1& C, const Operand2& A, const Operand3& B) const{
-			return BlasMatrixDomainSub<Field,Operand1,Operand2,Operand3>()(_F,C,A,B);
+			return BlasMatrixDomainSub<Operand1,Operand2,Operand3>()(C,A,B);
 		}
 
 		//! substraction (in place)
 		//! C -= B
 		template <class Operand1, class Operand3>
 		Operand1& subin(Operand1& C, const Operand3& B) const{
-			return BlasMatrixDomainSubin<Field,Operand1,Operand3>()(_F,C,B);
+			return BlasMatrixDomainSubin<Operand1,Operand3>()(C,B);
 		}
 
 		//! addition (in place)
 		//! C += B
 		template <class Operand1, class Operand3>
 		Operand1& addin(Operand1& C, const Operand3& B) const{
-			return BlasMatrixDomainAddin<Field,Operand1,Operand3>()(_F,C,B);
+			return BlasMatrixDomainAddin<Operand1,Operand3>()(C,B);
 		}
 
 		//! multiplication with scaling.
@@ -543,27 +543,26 @@ namespace LinBox{
 		//! A = A*B
 		template <class Operand1, class Operand2>
 		Operand1& mulin_left(Operand1& A, const Operand2& B) const{
-			return BlasMatrixDomainMulin<Field,Operand1,Operand2>()(_F,A,B);
+			return BlasMatrixDomainMulin<Operand1,Operand2>()(A,B);
 		}
 
 		//! In place multiplication.
 		//! B = A*B
 		template <class Operand1, class Operand2>
 		Operand2& mulin_right(const Operand1& A, Operand2& B) const{
-			return BlasMatrixDomainMulin<Field,Operand2,Operand1>()(_F,A,B);
+			return BlasMatrixDomainMulin<Operand2,Operand1>()(A,B);
 		}
 
 		//! axpy.
 		//! D = A*B + C
-		template <class Operand1, class Operand2, class Operand3>
-		Operand1& axpy(
-			Operand1& D,
-			const Operand2& A,
-			const Operand3& B,
-			const Operand1& C) const{
-
-			return muladd(D,_F.one,C,_F.one,A,B);
-		}
+                template <class Operand1, class Operand2, class Operand3, class Operand4>
+                Operand1& axpy(
+                    Operand1& D,
+                    const Operand3& A,
+                    const Operand4& B,
+                    const Operand2& C) const{
+                    return muladd(D,_F.one,C,_F.one,A,B);
+                }
 
 		//! axpyin.
 		//! C += A*B
@@ -574,12 +573,12 @@ namespace LinBox{
 
 		//! maxpy.
 		//! D = C - A*B
-		template <class Operand1, class Operand2, class Operand3>
+            template <class Operand1, class Operand2, class Operand3, class Operand4>
 		Operand1& maxpy(
 			Operand1& D,
-			const Operand2& A,
-			const Operand3& B,
-			const Operand1& C) const{
+			const Operand3& A,
+			const Operand4& B,
+			const Operand2& C) const{
 
 			return muladd(D,_F.one,C,_F.mOne,A,B);
 		}
@@ -593,12 +592,12 @@ namespace LinBox{
 
 		//! axmy.
 		//! D= A*B - C
-		template <class Operand1, class Operand2, class Operand3>
+                template <class Operand1, class Operand2, class Operand3, class Operand4>
 		Operand1& axmy(
 			Operand1& D,
-			const Operand2& A,
-			const Operand3& B,
-			const Operand1& C) const{
+			const Operand3& A,
+			const Operand4& B,
+			const Operand2& C) const{
 
 			return muladd(D,_F.mOne,C,_F.one,A,B);
 		}
@@ -612,16 +611,16 @@ namespace LinBox{
 
 		//!  general matrix-matrix multiplication and addition with scaling.
 		//! D= beta.C + alpha.A*B
-		template <class Operand1, class Operand2, class Operand3>
+		template <class Operand1, class Operand2, class Operand3,class Operand4>
 		Operand1& muladd(
 			Operand1& D,
 			const Element& beta,
-			const Operand1& C,
+			const Operand2& C,
 			const Element& alpha,
-			const Operand2& A,
-			const Operand3& B) const{
+			const Operand3& A,
+			const Operand4& B) const{
 
-			return BlasMatrixDomainMulAdd<Operand1,Operand2,Operand3>()(
+			return BlasMatrixDomainMulAdd<Operand1,Operand2,Operand3,Operand4>()(
 				D,
 				beta,
 				C,
@@ -640,7 +639,7 @@ namespace LinBox{
 			const Operand2& A,
 			const Operand3& B) const{
 
-			return BlasMatrixDomainMulAdd<Operand1,Operand2,Operand3>()(
+			return BlasMatrixDomainMulAdd<Operand1,Operand1,Operand2,Operand3>()(
 				_F,
 				beta,
 				C,
@@ -657,14 +656,14 @@ namespace LinBox{
 		//! Inversion
 		template <class Matrix>
 		Matrix& inv( Matrix &Ainv, const Matrix &A) const{
-			BlasMatrixDomainInv<Field,Matrix,Matrix>()(_F,Ainv,A);
+			BlasMatrixDomainInv<Matrix,Matrix>()(Ainv,A);
 			return Ainv;
 		}
 
 		//! Inversion (in place)
 		template <class Matrix>
 		Matrix& invin( Matrix &Ainv, Matrix &A) const{
-			BlasMatrixDomainInv<Field,Matrix,Matrix>()(_F,Ainv,A);
+			BlasMatrixDomainInv<Matrix,Matrix>()(Ainv,A);
 			return Ainv;
 		}
 
@@ -673,7 +672,7 @@ namespace LinBox{
 		Matrix& invin(Matrix &A) const{
 			Matrix tmp(A.rowdim(), A.coldim());
 			tmp = A;
-			BlasMatrixDomainInv<Field,Matrix,Matrix>()(_F,A,tmp);
+			BlasMatrixDomainInv<Matrix,Matrix>()(A,tmp);
 			return A;
 		}
 
@@ -689,39 +688,39 @@ namespace LinBox{
 		//! Inversion w singular check
 		template <class Matrix>
 		Matrix& inv(Matrix &Ainv, const Matrix &A, int& nullity) const{
-			nullity = BlasMatrixDomainInv<Field,Matrix,Matrix>()(_F,Ainv,A);
+			nullity = BlasMatrixDomainInv<Matrix,Matrix>()(Ainv,A);
 			return Ainv;
 		}
 
 		//! Inversion (the matrix A is modified) w singular check
 		template <class Matrix>
 		Matrix& invin(Matrix &Ainv, Matrix &A, int& nullity) const{
-			nullity = BlasMatrixDomainInv<Field,Matrix,Matrix>()(_F,Ainv,A);
+			nullity = BlasMatrixDomainInv<Matrix,Matrix>()(Ainv,A);
 			return Ainv;
 		}
 
 		//! Rank
 		template <class Matrix>
 		unsigned int rank(const Matrix &A) const{
-			return BlasMatrixDomainRank<Field,Matrix>()(_F,A);
+			return BlasMatrixDomainRank<Matrix>()(A);
 		}
 
 		//! in-place Rank (the matrix is modified)
 		template <class Matrix>
 		unsigned int rankInPlace(Matrix &A) const{
-			return BlasMatrixDomainRank<Field, Matrix>()(_F,A);
+			return BlasMatrixDomainRank<Matrix>()(A);
 		}
 
 		//! determinant
 		template <class Matrix>
 		Element det(const Matrix &A) const{
-			return BlasMatrixDomainDet<Field, Matrix>()(_F,A);
+			return BlasMatrixDomainDet<Matrix>()(A);
 		}
 
 		//! in-place Determinant (the matrix is modified)
 		template <class Matrix>
 		Element detInPlace(Matrix &A) const{
-			return BlasMatrixDomainDet<Field, Matrix>()(_F,A);
+			return BlasMatrixDomainDet<Matrix>()(A);
 		}
 		//@}
 
@@ -734,7 +733,7 @@ namespace LinBox{
 		//! AX=B
 		template <class Operand, class Matrix>
 		Operand& left_solve (Operand& X, const Matrix& A, const Operand& B) const{
-			return BlasMatrixDomainLeftSolve<Field,Operand,Matrix>()(_F,X,A,B);
+			return BlasMatrixDomainLeftSolve<Operand,Matrix>()(A,B);
 		}
 
 		//! linear solve with matrix right hand side, the result is stored in-place in B.
@@ -742,14 +741,14 @@ namespace LinBox{
 		//! AX=B , (B<-X)
 		template <class Operand,class Matrix>
 		Operand& left_solve (const Matrix& A, Operand& B) const{
-			return BlasMatrixDomainLeftSolve<Field,Operand,Matrix>()(_F,A,B);
+			return BlasMatrixDomainLeftSolve<Operand,Matrix>()(A,B);
 		}
 
 		//! linear solve with matrix right hand side.
 		//! XA=B
 		template <class Operand, class Matrix>
 		Operand& right_solve (Operand& X, const Matrix& A, const Operand& B) const{
-			return BlasMatrixDomainRightSolve<Field,Operand,Matrix>()(_F,X,A,B);
+			return BlasMatrixDomainRightSolve<Operand,Matrix>()(X,A,B);
 		}
 
 		//! linear solve with matrix right hand side, the result is stored in-place in B.
@@ -757,13 +756,13 @@ namespace LinBox{
 		//! XA=B , (B<-X)
 		template <class Operand, class Matrix>
 		Operand& right_solve (const Matrix& A, Operand& B) const{
-			return BlasMatrixDomainRightSolve<Field,Operand,Matrix>()(_F,A,B);
+			return BlasMatrixDomainRightSolve<Operand,Matrix>()(A,B);
 		}
 
 		//! minimal polynomial computation.
 		template <class Polynomial, class Matrix>
 		Polynomial& minpoly( Polynomial& P, const Matrix& A ) const{
-			return BlasMatrixDomainMinpoly<Field, Polynomial, Matrix>()(_F,P,A);
+			return BlasMatrixDomainMinpoly<Polynomial, Matrix>()(P,A);
 		}
 
 		//! characteristic polynomial computation.
@@ -773,10 +772,7 @@ namespace LinBox{
 			commentator().start ("Givaro::Modular Dense Charpoly ", "MDCharpoly");
 			std::list<Polynomial> P_list;
 			P_list.clear();
-			BlasMatrixDomainCharpoly<Field, std::list<Polynomial>, Matrix >()(
-				_F,
-				P_list,
-				A);
+			BlasMatrixDomainCharpoly<std::list<Polynomial>, Matrix >()(P_list,A);
 
 			Polynomial tmp(A.rowdim() + 1);
 			typename std::list<Polynomial>::iterator it = P_list.begin();
@@ -799,10 +795,7 @@ namespace LinBox{
 			std::list<Polynomial>& P,
 			const Matrix& A ) const{
 
-			return BlasMatrixDomainCharpoly<
-				Field,
-				std::list<Polynomial>,
-				Matrix >()(_F,P,A);
+			return BlasMatrixDomainCharpoly<std::list<Polynomial>,Matrix >()(P,A);
 		}
 
 
