@@ -81,7 +81,7 @@ namespace LinBox
 		}
 #endif
 
-		SparseMatrix<_Field, SparseMatrixFormat::ELL> (const _Field & F) :
+		SparseMatrix(const _Field & F) :
 			_rownb(0),_colnb(0)
 			,_maxc(0)
 			,_nbnz(0)
@@ -92,7 +92,7 @@ namespace LinBox
 		{
 		}
 
-		SparseMatrix<_Field, SparseMatrixFormat::ELL> (const _Field & F, size_t m, size_t n) :
+		SparseMatrix(const _Field & F, size_t m, size_t n) :
 			_rownb(m),_colnb(n)
 			,_maxc(0)
 			,_nbnz(0)
@@ -103,9 +103,7 @@ namespace LinBox
 		{
 		}
 
-		SparseMatrix<_Field, SparseMatrixFormat::ELL> (const _Field & F,
-							       size_t m, size_t n,
-							       size_t z) :
+		SparseMatrix(const _Field & F, size_t m, size_t n, size_t z) :
 			_rownb(m),_colnb(n)
 			, _maxc(0)
 			, _nbnz(z)
@@ -116,7 +114,7 @@ namespace LinBox
 		{
 		}
 
-		SparseMatrix<_Field, SparseMatrixFormat::ELL> (const SparseMatrix<_Field, SparseMatrixFormat::CSR> & S) :
+		SparseMatrix(const SparseMatrix<_Field, SparseMatrixFormat::CSR> & S) :
 			_rownb(S._rownb),_colnb(S._colnb)
 			,_maxc(S._maxc)
 			,_nbnz(S._nbnz)
@@ -219,7 +217,7 @@ namespace LinBox
 
 
 		template<class VectStream>
-		SparseMatrix<_Field, SparseMatrixFormat::ELL> (const _Field & F, VectStream & stream) :
+		SparseMatrix(const _Field & F, VectStream & stream) :
 			_rownb(stream.size()),_colnb(stream.dim())
 			, _maxc(0)
 			, _nbnz(0)
@@ -233,7 +231,7 @@ namespace LinBox
 			finalize();
 		}
 
-		SparseMatrix<_Field, SparseMatrixFormat::ELL> ( MatrixStream<Field>& ms ):
+		SparseMatrix( MatrixStream<Field>& ms ):
 			_rownb(0),_colnb(0)
 			,_maxc(0)
 			,_nbnz(0)
@@ -305,7 +303,7 @@ namespace LinBox
 		 * @param S a sparse matrix in any storage.
 		 */
 		template<class _OtherStorage>
-		SparseMatrix<_Field, SparseMatrixFormat::ELL> (const SparseMatrix<_Field, _OtherStorage> & S) :
+		SparseMatrix(const SparseMatrix<_Field, _OtherStorage> & S) :
 			_rownb(S.rowdim()),_colnb(S.coldim())
 			,_nbnz(S.size())
 			,_maxc(0)
@@ -1210,10 +1208,10 @@ namespace LinBox
 				_colid_beg = iter._colid_beg ;
 				_colid_it  = iter._colid_it ;
 				_data_it   = iter._data_it  ;
-				_data_beg  = iter._data_beg ;
-				_data_end  = iter._data_end  ;
-				_field     = iter._field ;
-				_ld        = iter._ld ;
+				const_cast<data_it>(_data_beg)  = iter._data_beg ;
+				const_cast<data_it>(_data_end)  = iter._data_end  ;
+				const_cast<Field &>(_field)     = iter._field ;
+				const_cast<size_t&>(_ld)        = iter._ld ;
 				_row       = iter._row ;
 
 				return *this;
