@@ -44,7 +44,7 @@
 // #include "linbox/vector/subvector.h"
 #include "linbox/matrix/matrix-traits.h"
 // #include "linbox/vector/stream.h"
-#include "linbox/matrix/matrix-domain.h"
+//#include "linbox/matrix/matrix-domain.h"
 
 namespace LinBox
 {
@@ -83,8 +83,8 @@ namespace LinBox
 	template <class Matrix, class Trait = typename MatrixTraits<Matrix>::MatrixCategory>
 	class TransposeMatrix {
 	public:
-
-		typedef typename Matrix::Element Element;
+        typedef typename Matrix::Field Field;
+		typedef typename Field::Element Element;
 
 		typedef typename Matrix::ColIterator RowIterator;
 		typedef typename Matrix::RowIterator ColIterator;
@@ -112,6 +112,12 @@ namespace LinBox
 			_Mat (Mat._Mat)
 		{}
 
+
+        /** Get the field of  the matrix
+		 * @return field of the matrix
+		 */
+        inline const Field& field() const {return _Mat.field();}
+        
 		/** Get the number of rows in the matrix
 		 * @return Number of rows in matrix
 		 */
@@ -154,7 +160,7 @@ namespace LinBox
 		 * @param j Column number 0...coldim () - 1
 		 * @param a_ij Element to set
 		 */
-		const Element& setEntry (size_t i, size_t j, const Element &a_ij)
+		void setEntry (size_t i, size_t j, const Element &a_ij)
 		{
 			return _Mat.setEntry (j, i, a_ij);
 		}
@@ -301,8 +307,8 @@ namespace LinBox
 	template <class Matrix>
 	class TransposeMatrix<Matrix, MatrixCategories::RowColMatrixTag> {
 	public:
-
-		typedef typename Matrix::Element Element;
+        typedef typename Matrix::Field Field;
+		typedef typename Field::Element Element;
 
 		typedef typename Matrix::ColIterator RowIterator;
 		typedef typename Matrix::RowIterator ColIterator;
@@ -325,6 +331,8 @@ namespace LinBox
 			_Mat (Mat._Mat)
 		{}
 
+        inline const Field& field() const {return _Mat.field();}
+
 		inline size_t rowdim () const
 		{
 			return _Mat.coldim ();
@@ -339,7 +347,7 @@ namespace LinBox
 			return _Mat.write (stream);
 		}
 
-		inline const Element& setEntry (size_t i, size_t j, const Element &a_ij)
+		inline void setEntry (size_t i, size_t j, const Element &a_ij)
 		{
 			return _Mat.setEntry (j, i, a_ij);
 		}
@@ -434,9 +442,8 @@ namespace LinBox
 	template <class Matrix>
 	class TransposeMatrix<Matrix, MatrixCategories::RowMatrixTag> {
 	public:
-
-		typedef typename Matrix::Element Element;
-
+        typedef typename Matrix::Field Field;
+		typedef typename Field::Element Element;
 		typedef typename Matrix::RowIterator ColIterator;
 		typedef typename Matrix::Iterator Iterator;
 		typedef typename Matrix::IndexedIterator IndexedIterator;
@@ -456,6 +463,8 @@ namespace LinBox
 			_Mat (Mat._Mat)
 		{}
 
+        inline const Field& field() const {return _Mat.field();}
+
 		inline size_t rowdim () const
 		{
 			return _Mat.coldim ();
@@ -470,7 +479,7 @@ namespace LinBox
 			return _Mat.write (stream);
 		}
 
-		inline const Element& setEntry (size_t i, size_t j, const Element &a_ij)
+		inline void setEntry (size_t i, size_t j, const Element &a_ij)
 		{
 			return _Mat.setEntry (j, i, a_ij);
 		}
@@ -548,9 +557,8 @@ namespace LinBox
 	template <class Matrix>
 	class TransposeMatrix<Matrix, MatrixCategories::ColMatrixTag> {
 	public:
-
-		typedef typename Matrix::Element Element;
-
+        typedef typename Matrix::Field Field;
+		typedef typename Field::Element Element;
 		typedef typename Matrix::ColIterator RowIterator;
 		typedef typename Matrix::Iterator Iterator;
 		typedef typename Matrix::IndexedIterator IndexedIterator;
@@ -567,6 +575,8 @@ namespace LinBox
 			_Mat (Mat._Mat)
 		{}
 
+        inline const Field& field() const {return _Mat.field();}
+
 		inline size_t rowdim () const
 		{
 			return _Mat.coldim ();
@@ -581,7 +591,7 @@ namespace LinBox
 			return _Mat.write (stream);
 		}
 
-		inline const Element& setEntry (size_t i, size_t j, const Element &a_ij)
+		inline void setEntry (size_t i, size_t j, const Element &a_ij)
 		{
 			return _Mat.setEntry (j, i, a_ij);
 		}
