@@ -1,4 +1,3 @@
-
 /* linbox/randiter/modular-balanced.h
  * Copyright (C) 1999-2005 William J Turner,
  *               2002 Bradford Hovinen
@@ -63,8 +62,9 @@
 namespace LinBox
 {
 
-	template <class Element>
-	class ModularBalanced;
+#if 0
+	 template <class Element>
+	 class Givaro::ModularBalanced<Element>;
 
 	/** Random field base element generator.
 	 * This encapsulated class is a generator of random field base elements for
@@ -79,7 +79,7 @@ namespace LinBox
 	 * and also returned as a reference.
 	 */
 	template <class Element>
-	class ModularBalancedRandIter {
+	class Givaro::ModularBalancedRandIter {
 	public:
 
 		/** Constructor from field, sampling size, and seed.
@@ -95,9 +95,9 @@ namespace LinBox
 		 * @param seed constant integer reference from which to seed random number
 		 *             generator (default = 0)
 		 */
-		ModularBalancedRandIter (const ModularBalanced<Element> &F,
+		Givaro::ModularBalancedRandIter (const Givaro::ModularBalanced<Element> &F,
 					 const integer &size = 0,
-					 const integer &seed = 0) :
+					 const unit64_t seed = 0) :
 			_field (F), _size (size), _seed (seed)
 		{
 			if (_seed == 0) _seed = time (NULL);
@@ -118,30 +118,31 @@ namespace LinBox
 		}
 
 		/** Copy constructor.
-		 * Constructs ModularBalancedRandIter object by copying the random field
+		 * Constructs Givaro::ModularBalancedRandIter object by copying the random field
 		 * element generator.
 		 * This is required to allow generator objects to be passed by value
 		 * into functions.
-		 * @param  R ModularBalancedRandIter object.
+		 * @param  R Givaro::ModularBalancedRandIter object.
 		 */
-		ModularBalancedRandIter (const ModularBalancedRandIter<Element> &R) :
+		Givaro::ModularBalancedRandIter (const Givaro::ModularBalancedRandIter<Element> &R) :
 			_field (R._field), _size (R._size), _seed (R._seed)
 		{}
 
 		/** Destructor.
 		 * This destructs the random field element generator object.
 		 */
-		~ModularBalancedRandIter () {}
+		~Givaro::ModularBalancedRandIter () {}
 
 		/** Assignment operator.
-		 * Assigns ModularBalancedRandIter object R to generator.
-		 * @param  R ModularBalancedRandIter object.
+		 * Assigns Givaro::ModularBalancedRandIter object R to generator.
+		 * @param  R Givaro::ModularBalancedRandIter object.
 		 */
-		ModularBalancedRandIter<Element> &operator=(const ModularBalancedRandIter<Element> &R)
+		Givaro::ModularBalancedRandIter<Element> &operator=(const Givaro::ModularBalancedRandIter<Element> &R)
 		{
 			if (this != &R) { // guard against self-assignment
 				_size = R._size;
 				_seed = R._seed;
+				_field = R._field;
 			}
 
 			return *this;
@@ -168,31 +169,29 @@ namespace LinBox
 			Element tmp;
 
 			random (tmp);
-			return (a = ElementEnvelope <ModularBalanced<Element> > (tmp));
+			return (a = ElementEnvelope <Givaro::ModularBalanced<Element> > (tmp));
 		}
 
 	private:
 		/// Field in which arithmetic is done
-		ModularBalanced<Element> _field;
+		Givaro::ModularBalanced<Element> _field;
 
 		/// Sampling size
 		integer _size;
 
 		/// Seed
-		long _seed;
-
-	}; // class ModularBalancedRandIter
+		uint64_t _seed;
 
+	}; // class Givaro::ModularBalancedRandIter
+#endif
 } // namespace LinBox
 
 #endif //__LINBOX_randiter_modular_balanced_H
 
-
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,:0,t0,+0,=s
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
