@@ -37,12 +37,6 @@
 #include "linbox/randiter/envelope.h"
 
 #include "linbox/linbox-config.h"
-#ifdef __LINBOX_XMLENABLED
-
-#include "linbox/util/xml/linbox-reader.h"
-#include "linbox/util/xml/linbox-writer.h"
-
-#endif
 
 // Namespace in which all LinBox code resides
 namespace LinBox
@@ -104,11 +98,11 @@ namespace LinBox
 		       	FieldEnvelope<Ring> (E._field)
 		{}
 
-#ifdef __LINBOX_XMLENABLED
-		RingEnvelope(Reader &R) :
-		       	FieldEnvelope<Ring>(R)
-	       	{}
-#endif
+// #ifdef __LINBOX_XMLENABLED
+// 		RingEnvelope(Reader &R) :
+// 		       	FieldEnvelope<Ring>(R)
+// 	       	{}
+// #endif
 
 
 		/** Virtual copy constructor.
@@ -297,12 +291,10 @@ namespace LinBox
 
 #endif // __LINBOX_ring_envelope_H
 
-
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,:0,t0,+0,=s
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
