@@ -30,12 +30,11 @@
 
 
 #include <cmath>
-#include <givaro/modular-int32.h>
+#include <givaro/modular-integral.h>
 
 #include "linbox/linbox-config.h"
 #include "linbox/integer.h"
 #include "linbox/vector/vector-domain.h"
-#include "linbox/field/field-interface.h"
 #include "linbox/field/field-traits.h"
 #include "linbox/ring/modular.h"
 #include "linbox/util/debug.h"
@@ -393,11 +392,10 @@ namespace LinBox
 
 #endif //__LINBOX_modular_int32_H
 
-
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
