@@ -42,7 +42,7 @@ namespace LinBox
 	 * black box, is computed over the ring or field of A.
 	 *
 	 * @param A Black box of which to compute the isPositiveDefinite
-	 * @param M may be a Method::Hybrid (default), Method::Blackbox, Method::Elimination, or of other method type.
+	 * @param M may be a Method::Auto (default), Method::Blackbox, Method::Elimination, or of other method type.
 	 \ingroup isPositiveDefinites
 	 */
 	template <class Blackbox, class MyMethod>
@@ -58,7 +58,7 @@ namespace LinBox
 	bool isPositiveDefinite ( const Blackbox  &A)
 	{
 		return isPositiveDefinite(A,
-					  Method::Hybrid());
+					  Method::Auto());
 	}
 
 	// The isPositiveDefinite for ModularTag (is nonsense)
@@ -73,18 +73,21 @@ namespace LinBox
 		return false;
 	}
 
-	// The isPositiveDefinite with Hybrid Method
+	// The isPositiveDefinite with Auto Method
 	template<class Blackbox>
 	bool isPositiveDefinite (
 				 const Blackbox 			&A,
 				 const RingCategories::IntegerTag          &tag,
-				 const Method::Hybrid& M)
+				 const Method::Auto& M)
 	{
-		// should try a modular minpoly and decide on the degree of that...
-		if (A.rowdim() != A.coldim()) return false;
-		// this crude size check can be refined
-		if (A.coldim() > 7000) return isPositiveDefinite(A, tag, Method::Blackbox(M));
-		else return isPositiveDefinite(A, tag, Method::Elimination(M));
+		//! @bug should try a modular minpoly and decide on the degree of that...
+		if (A.rowdim() != A.coldim())
+		       	return false;
+		//! @bug this crude size check can be refined
+		if (A.coldim() > 7000)
+		       	return isPositiveDefinite(A, tag, Method::Blackbox(M));
+		else
+		       	return isPositiveDefinite(A, tag, Method::Elimination(M));
 	}
 
 	// The isPositiveDefinite with Elimination Method
@@ -94,11 +97,11 @@ namespace LinBox
 				 const RingCategories::IntegerTag          &tag,
 				 const Method::Elimination& M)
 	{
-		// this can be a hybrid of EliminationMinpoly and BlasElimination (which means use LU here)
+		// this can be a hybrid of EliminationMinpoly and DenseElimination (which means use LU here)
 		// It will be faster to do EliminationMinpoly when deg(m_A) is low.
 
-		// right now it is just BlasElimination
-		return isPositiveDefinite(A, tag, Method::BlasElimination(M));
+		// right now it is just DenseElimination
+		return isPositiveDefinite(A, tag, Method::DenseElimination(M));
 	}
 
 	// The isPositiveDefinite with BlackBox Method
@@ -128,11 +131,11 @@ namespace LinBox
 	bool isPositiveDefinite (
 				 const Blackbox                      &A,
 				 const RingCategories::IntegerTag    &tag,
-				 const Method::BlasElimination       &M)
+				 const Method::DenseElimination       &M)
 	{
-		// call BlasElimination code
+		// call DenseElimination code
 		BlasMatrix<typename Blackbox::Field> DA(A.field(), A.rowdim(), A.coldim());
-		MatrixHom::map(DA, A, A. field());
+		MatrixHom::map(DA, A); //! @bug why map (same field)? This is a copy.
 		return Signature::isPosDef(DA, Signature::BLAS_LPM_Method() );
 	}
 
@@ -140,9 +143,9 @@ namespace LinBox
 	bool isPositiveDefinite (
 				 const BlasMatrix<Ring> &A,
 				 const RingCategories::IntegerTag    &tag,
-				 const Method::BlasElimination       &M)
+				 const Method::DenseElimination       &M)
 	{
-		// call BlasElimination code
+		// call DenseElimination code
 		return Signature::isPosDef(A, Signature::BLAS_LPM_Method() );
 	}
 
@@ -151,12 +154,10 @@ namespace LinBox
 
 #endif // __LINBOX_is_positive_definite_H
 
-
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,:0,t0,+0,=s
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
