@@ -64,34 +64,34 @@ namespace LinBox
 	 * For very large and/or very sparse matrices the Wiedemann method will be faster
 	 * (and it is memory efficient).
 	 * For some sparse matrices SparseElimination may outperform Wiedemann.
-	 * For small or dense matrices BlasElimination will be faster.
+	 * For small or dense matrices DenseElimination will be faster.
 	 * \param[out] r  output rank of A.
 	 * \param[in]  A linear transform, member of any blackbox class.
-	 * \param[in]  M may be a \p Method::Hybrid (the default), a \p Method::Wiedemann, a  \p Method::BlasElimination, or a \p Method::SparseElimination..
+	 * \param[in]  M may be a \p Method::Auto (the default), a \p Method::Wiedemann, a  \p Method::DenseElimination, or a \p Method::SparseElimination..
 	 * \param      tag UNDOC
 	 * \return a reference to r.
 	 */
 	template <class Blackbox, class Method, class DomainCategory>
-	inline unsigned long &rank (unsigned long &r, const Blackbox &A, 
+	inline size_t &rank (size_t &r, const Blackbox &A,
 			const DomainCategory &tag, const Method &M);
 
 	template <class Blackbox, class Method, class DomainCategory>
-	inline unsigned long &rankin (unsigned long &r, const Blackbox &A, 
+	inline size_t &rankInPlace (size_t &r, Blackbox &A,
 			const DomainCategory &tag, const Method &M);
 
 	/**
 	 * Compute the rank of a linear transform A over a field.
 	 * \ingroup solutions
 	 * The default method is Wiedemann(), using diagonal preconditioning and
-	 * the minpoly.  For small or dense matrices BlasElimination will be faster.
+	 * the minpoly.  For small or dense matrices DenseElimination will be faster.
 	 * \param      A linear transform, member of any blackbox class.
 	 * \param[out] r rank of \p A
 	 * \return     \p r rank of \p A.
 	  */
 	template <class Blackbox>
-	inline unsigned long &rank (unsigned long &r, const Blackbox &A)
+	inline size_t &rank (size_t &r, const Blackbox &A)
 	{
-		return rank(r, A, typename FieldTraits<typename Blackbox::Field>::categoryTag(), Method::Hybrid());
+		return rank(r, A, typename FieldTraits<typename Blackbox::Field>::categoryTag(), Method::Auto());
 	}
 
 	/**
@@ -99,14 +99,14 @@ namespace LinBox
 	 * \ingroup solutions
 	 *
 	 * The default method is \p Wiedemann(), using diagonal preconditioning and
-	 * the minpoly.  For small or dense matrices \p BlasElimination will be faster.
+	 * the minpoly.  For small or dense matrices \p DenseElimination will be faster.
 	 * \return \p r rank of \p A.
 	 * \param A linear transform, member of any blackbox class.
 	 * @param[out] r rank of \p A
 	 * @param M method (see ???)
 	 */
 	template <class Blackbox, class Method>
-	inline unsigned long &rank (unsigned long &r, const Blackbox &A,
+	inline size_t &rank (size_t &r, const Blackbox &A,
 				    const Method &M)
 	{
 		return rank(r, A, typename FieldTraits<typename Blackbox::Field>::categoryTag(), M);
@@ -118,10 +118,10 @@ namespace LinBox
 	 * @param r rank
 	*/
 	template <class Blackbox>
-	inline unsigned long &rankin (unsigned long &r, Blackbox &A)
+	inline size_t &rankInPlace (size_t &r, Blackbox &A)
 	{
 		//! @bug there is no Elimination() method there.
-		return rankin(r, A, typename FieldTraits<typename Blackbox::Field>::categoryTag(), Method::SparseElimination());
+		return rankInPlace(r, A, typename FieldTraits<typename Blackbox::Field>::categoryTag(), Method::SparseElimination());
 	}
 
 
@@ -132,11 +132,10 @@ namespace LinBox
 
 #endif // __LINBOX_rank_H
 
-
 // Local Variables:
 // mode: C++
 // tab-width: 4
 // indent-tabs-mode: nil
 // c-basic-offset: 4
 // End:
-// vim:sts=4:sw=4:ts=4:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
