@@ -165,8 +165,8 @@ namespace LinBox
 		 * @param m Number of vectors to return (0 for unlimited)
 		 */
 		ConstantVectorStream (Vector &v, size_t m) :
-		       	_v (v), _m (m), _j (0)
-	       	{}
+			_v (v), _m (m), _j (0)
+		{}
 
 		/** Retrieve vector
 		 * @param v Vector to use
@@ -214,7 +214,7 @@ namespace LinBox
 }
 
 
-// #include "linbox/vector/blas-vector.h"
+//#include "linbox/vector/blas-vector.h"
 // Dense
 namespace LinBox
 {
@@ -337,7 +337,7 @@ namespace LinBox
 		 * @param m Number of vectors to return (0 for unlimited)
 		 * @param seed
 		 */
-		RandomSparseStream (const Field &F, RandIter &r, double p, size_t n, size_t m = 0, int seed=(int)time (NULL));
+		RandomSparseStream (const Field &F, RandIter &r, double p, size_t n, size_t m = 0, uint64_t seed=(uint64_t)time (NULL));
 
 		/** Get next element
 		 * @param v Vector into which to generate random vector
@@ -381,9 +381,9 @@ namespace LinBox
 		typedef _Vector Vector;
 		typedef RandomSparseStream<Field, Vector, RandIter, VectorCategories::DenseVectorTag > Self_t;
 
-		RandomSparseStream (const Field &F, RandIter &r, double p, size_t n, size_t m = 0, int seed=(int)time (NULL)) :
+		RandomSparseStream (const Field &F, RandIter &r, double p, size_t n, size_t m = 0, uint64_t seed=(uint64_t)time (NULL)) :
 			_field (F), _r1 (r), _r (_r1), _n (n), _p (p), _m (m), _j (0),
-			MT ((uint32_t)seed)
+			MT (static_cast<uint32_t>(seed))
 		{
 			linbox_check ((p >= 0.0) && (p <= 1.0));
 		}
@@ -437,15 +437,15 @@ namespace LinBox
 		typedef _Vector Vector;
 
 		RandomSparseStream (const Field &F, RandIter &r, double p,
-				    size_t N, size_t M = 0, int seed=(int)time (NULL)) :
-                _field (F), 
-                _r1 (r), 
-                _r (r), 
-                _n (N), 
-                _p (p), 
-                _m (M), 
+				    size_t N, size_t M = 0, uint64_t seed= time (NULL)) :
+                _field (F),
+                _r1 (r),
+                _r (r),
+                _n (N),
+                _p (p),
+                _m (M),
                 _j (0),
-                MT ((uint32_t)seed)
+                MT (static_cast<uint32_t>(seed))
 		{ setP (p); }
 
 		Vector &get (Vector &v)
@@ -517,9 +517,9 @@ namespace LinBox
 		typedef RandomSparseStream<Field, Vector, RandIter, VectorCategories::SparseAssociativeVectorTag > Self_t;
 
 		RandomSparseStream (const Field &F, RandIter &r, double p, size_t N,
-				    size_t M = 0, int seed=(int)time (NULL)) :
+				    size_t M = 0, uint64_t seed= time (NULL)) :
 			_field (F), _r1 (r), _r (_r1), _n (N), _k ((long) (p * N)), _j (0), _m (M),
-			MT ((uint32_t) seed)
+			MT (static_cast<uint32_t>(seed))
 		{}
 
 		Vector &get (Vector &v)
@@ -571,9 +571,9 @@ namespace LinBox
 		typedef _Vector Vector;
 		typedef RandomSparseStream<Field, Vector, RandIter, VectorCategories::SparseParallelVectorTag > Self_t;
 
-		RandomSparseStream (const Field &F, RandIter &r, double p, size_t nn, size_t mm = 0, int seed=(int)time (NULL)) :
+		RandomSparseStream (const Field &F, RandIter &r, double p, size_t nn, size_t mm = 0, uint64_t  seed= time (NULL)) :
 			_field (F), _r1 (r), _r (_r1), _n (nn), _m (mm), _j (0),
-			MT ((uint32_t)seed)
+			MT (static_cast<uint32_t>(seed))
 		{ setP (p); }
 
 		Vector &get (Vector &v)
@@ -873,12 +873,10 @@ namespace LinBox
 
 #endif // __LINBOX_vector_stream_H
 
-
-
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
